<?php return array (
  'components' => 
  array (
    'db' => 
    array (
      'username' => '[[softdbuser]]',
      'password' => '[[softdbpass]]',
      'dsn' => 'mysql:host=[[softdbhost]];dbname=[[softdb]]',
    ),
  ),
);